unofficial mirror of bug-gnu-emacs@gnu.org 
 help / color / mirror / code / Atom feed
* 27.1; add libera chat to ERC
@ 2021-05-20  2:27 Corwin Brust
  2021-05-24 21:36 ` Lars Ingebrigtsen
  2021-05-24 22:03 ` bug#48529: " Andreas Schwab
  0 siblings, 2 replies; 5+ messages in thread
From: Corwin Brust @ 2021-05-20  2:27 UTC (permalink / raw)
  To: bug-gnu-emacs; +Cc: emacs-erc, bandali

[-- Attachment #1: Type: text/plain, Size: 1171 bytes --]

Hi Emacs Maintainers &thanks,

A new IRC network was recently created expressly for development of Free
(or also, *boo, hiss* open-source ;) software.

Can we add this patch to make ERC able to connect to this new network
available to users "out of the box"?

Here is a similar request for HexChat:
https://github.com/hexchat/hexchat/pull/2566/files

I don't see any reason we would hurry to apply this.  While I do expect
the new network to be 'around for the future', I also think those most
affected of "our users" (e.g. using IRC heavily, and for developing
free software)
are likely aware.  It would be very nice to have with the next major release
(meaning 28 and not anything 27.x).

I haven't completed my assignment paperwork (ug, someday soon, I hope).
Hopefully this qualifies as a "tiny change".  In any case, it *seems* trivial
enough.

I didn't make any news entry for the attached "starter" patch; it
would probably warrant one.

Memory information:
((conses 16 53831 9092)
 (symbols 48 6967 1)
 (strings 32 18643 1538)
 (string-bytes 1 544490)
 (vectors 16 9262)
 (vector-slots 8 123404 10290)
 (floats 8 22 305)
 (intervals 56 222 0)
 (buffers 1000 11))

[-- Attachment #2: emacs_erc_add_libera.patch --]
[-- Type: application/octet-stream, Size: 1404 bytes --]

diff --git a/lisp/erc/erc-services.el b/lisp/erc/erc-services.el
index 09d1f7a330..62c9fbdd51 100644
--- a/lisp/erc/erc-services.el
+++ b/lisp/erc/erc-services.el
@@ -32,8 +32,8 @@
 
 ;; As a default, ERC has the data for the official nickname services on
 ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
 ;; and Slashnet.  You can add more by using M-x customize-variable RET
 ;; erc-nickserv-alist.
 
 ;; Usage:
 ;;
@@ -197,6 +197,7 @@ Example of use:
 			(const GalaxyNet)
 			(const GRnet)
 			(const iip)
+                        (const Libera)
 			(const OFTC)
 			(const QuakeNet)
 			(const Rizon)
@@ -264,6 +265,15 @@ Example of use:
      "type\\s-/squery\\s-Trent\\s-identify\\s-<password>"
      "Trent@anon.iip"
      "IDENTIFY" nil "SQUERY" nil)
+    (Libera
+     "NickServ!NickServ@services."
+     ;; Libera.Chat also accepts a password at login, see the `erc'
+     ;; :password argument.
+     "This\\s-nickname\\s-is\\s-registered.\\s-Please\\s-choose"
+     "NickServ"
+     "IDENTIFY" nil nil
+     ;; See also the 901 response code message.
+     "You\\s-are\\s-now\\s-identified\\s-for\\s-")
     (OFTC
      "NickServ!services@services.oftc.net"
      ;; OFTC's NickServ doesn't ask you to identify anymore.

^ permalink raw reply related	[flat|nested] 5+ messages in thread

* Re: 27.1; add libera chat to ERC
  2021-05-20  2:27 27.1; add libera chat to ERC Corwin Brust
@ 2021-05-24 21:36 ` Lars Ingebrigtsen
  2021-05-24 22:03 ` bug#48529: " Andreas Schwab
  1 sibling, 0 replies; 5+ messages in thread
@@ -32,8 +32,8 @@
 ;; As a default, ERC has the data for the official nickname services on
 ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
-;; and Slashnet.  You can add more by using M-x customize-variable RET
-;; erc-nickserv-alist.
+;; Libera.Chat and Slashnet.  You can add more by using
+;;   M-x customize-variable RET erc-nickserv-alist.
 
 ;; Usage:
From: Lars Ingebrigtsen @ 2021-05-24 21:36 UTC (permalink / raw)
  To: Corwin Brust; +Cc: bug-gnu-emacs, emacs-erc, bandali

Corwin Brust <corwin@bru.st> writes:

> Can we add this patch to make ERC able to connect to this new network
> available to users "out of the box"?

Thanks; added to Emacs 28.

-- 
(domestic pets only, the antidote for overdose, milk.)
   bloggy blog: http://lars.ingebrigtsen.no



^ permalink raw reply	[flat|nested] 5+ messages in thread

* bug#48529: 27.1; add libera chat to ERC
  2021-05-20  2:27 27.1; add libera chat to ERC Corwin Brust
  2021-05-24 21:36 ` Lars Ingebrigtsen
@ 2021-05-24 22:03 ` Andreas Schwab
  2021-05-25  2:39   ` Alex Murray
  1 sibling, 1 reply; 5+ messages in thread
From: Andreas Schwab @ 2021-05-24 22:03 UTC (permalink / raw)
  To: Corwin Brust; +Cc: emacs-erc, bandali, 48529

On Mai 19 2021, Corwin Brust wrote:

> diff --git a/lisp/erc/erc-services.el b/lisp/erc/erc-services.el
> index 09d1f7a330..62c9fbdd51 100644
> --- a/lisp/erc/erc-services.el
> +++ b/lisp/erc/erc-services.el
> @@ -32,8 +32,8 @@
>  
>  ;; As a default, ERC has the data for the official nickname services on
>  ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
> -;; and Slashnet.  You can add more by using M-x customize-variable RET
> -;; erc-nickserv-alist.
> +;; Libera.Chat and Slashnet.  You can add more by using
> +;;   M-x customize-variable RET erc-nickserv-alist.
>  
>  ;; Usage:
>  ;;
> @@ -197,6 +197,7 @@ Example of use:
>  			(const GalaxyNet)
>  			(const GRnet)
>  			(const iip)
> +                        (const Libera)
>  			(const OFTC)
>  			(const QuakeNet)
>  			(const Rizon)
> @@ -264,6 +265,15 @@ Example of use:
>       "type\\s-/squery\\s-Trent\\s-identify\\s-<password>"
>       "Trent@anon.iip"
>       "IDENTIFY" nil "SQUERY" nil)
> +    (Libera
> +     "NickServ!NickServ@services."
> +     ;; Libera.Chat also accepts a password at login, see the `erc'
> +     ;; :password argument.
> +     "This\\s-nickname\\s-is\\s-registered.\\s-Please\\s-choose"
> +     "NickServ"
> +     "IDENTIFY" nil nil
> +     ;; See also the 901 response code message.
> +     "You\\s-are\\s-now\\s-identified\\s-for\\s-")
>      (OFTC
>       "NickServ!services@services.oftc.net"
>       ;; OFTC's NickServ doesn't ask you to identify anymore.

irc.libera.chat identifies itself as Libera.Chat.  Shouldn't that be
used instead of Libera?

Andreas.

-- 
Andreas Schwab, schwab@linux-m68k.org
GPG Key fingerprint = 7578 EB47 D4E5 4D69 2510  2552 DF73 E780 A9DA AEC1
"And now for something completely different."





^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: 27.1; add libera chat to ERC
  2021-05-24 22:03 ` bug#48529: " Andreas Schwab
@ 2021-05-25  2:39   ` Alex Murray
  2021-05-25  3:31     ` bug#48529: " bandali
  0 siblings, 1 reply; 5+ messages in thread
From: Alex Murray @ 2021-05-25  2:39 UTC (permalink / raw)
  To: Andreas Schwab; +Cc: bug-gnu-emacs, bandali, emacs-erc


On Tue, 2021-05-25 at 07:33:31 +0930, Andreas Schwab wrote:

> On Mai 19 2021, Corwin Brust wrote:
>
>> diff --git a/lisp/erc/erc-services.el b/lisp/erc/erc-services.el
>> index 09d1f7a330..62c9fbdd51 100644
>> --- a/lisp/erc/erc-services.el
>> +++ b/lisp/erc/erc-services.el
>> @@ -32,8 +32,8 @@
>>  
>>  ;; As a default, ERC has the data for the official nickname services on
>>  ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
>> -;; and Slashnet.  You can add more by using M-x customize-variable RET
>> -;; erc-nickserv-alist.
>> +;; Libera.Chat and Slashnet.  You can add more by using
>> +;;   M-x customize-variable RET erc-nickserv-alist.
>>  
>>  ;; Usage:
>>  ;;
>> @@ -197,6 +197,7 @@ Example of use:
>>  			(const GalaxyNet)
>>  			(const GRnet)
>>  			(const iip)
>> +                        (const Libera)
>>  			(const OFTC)
>>  			(const QuakeNet)
>>  			(const Rizon)
>> @@ -264,6 +265,15 @@ Example of use:
>>       "type\\s-/squery\\s-Trent\\s-identify\\s-<password>"
>>       "Trent@anon.iip"
>>       "IDENTIFY" nil "SQUERY" nil)
>> +    (Libera
>> +     "NickServ!NickServ@services."

NickServ on irc.libera.chat shows as:

NickServ is Nickname Services (NickServ@services.libera.chat)


So I think the above should be:

+     "NickServ!NickServ@services.libera.chat"

>> +     ;; Libera.Chat also accepts a password at login, see the `erc'
>> +     ;; :password argument.
>> +     "This\\s-nickname\\s-is\\s-registered.\\s-Please\\s-choose"
>> +     "NickServ"
>> +     "IDENTIFY" nil nil
>> +     ;; See also the 901 response code message.
>> +     "You\\s-are\\s-now\\s-identified\\s-for\\s-")
>>      (OFTC
>>       "NickServ!services@services.oftc.net"
>>       ;; OFTC's NickServ doesn't ask you to identify anymore.
>
> irc.libera.chat identifies itself as Libera.Chat.  Shouldn't that be
> used instead of Libera?
>
> Andreas.




^ permalink raw reply	[flat|nested] 5+ messages in thread

* bug#48529: 27.1; add libera chat to ERC
  2021-05-25  2:39   ` Alex Murray
@ 2021-05-25  3:31     ` bandali
  0 siblings, 0 replies; 5+ messages in thread
From: bandali @ 2021-05-25  3:31 UTC (permalink / raw)
  To: Alex Murray; +Cc: emacs-erc, Andreas Schwab, 48529-done

Alex Murray writes:

> On Tue, 2021-05-25 at 07:33:31 +0930, Andreas Schwab wrote:
>
[...]
>
> So I think the above should be:
>
> +     "NickServ!NickServ@services.libera.chat"
>
[...]
>>
>> irc.libera.chat identifies itself as Libera.Chat.  Shouldn't that be
>> used instead of Libera?
>>
>> Andreas.
>
>
>

Thanks.  Yes, and yes; now fixed.





^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2021-05-25  3:31 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2021-05-20  2:27 27.1; add libera chat to ERC Corwin Brust
2021-05-24 21:36 ` Lars Ingebrigtsen
2021-05-24 22:03 ` bug#48529: " Andreas Schwab
2021-05-25  2:39   ` Alex Murray
2021-05-25  3:31     ` bug#48529: " bandali

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).